@@ -68,8 +68,7 @@ func Test_WildcardMatchingOnRequiredLabels(t *testing.T) {
 			DefaultSeverity: severity.High,
 			CheckFunc: func(set result.Set, rootBlock block.Block, ctx *hclcontext.Context) {
 				set.Add(
-					result.New(rootBlock).WithDescription(fmt.Sprintf("Custom check failed for resource %s.", rootBlock.FullName())).
-						WithRange(rootBlock.Range()),
+					result.New(rootBlock).WithDescription(fmt.Sprintf("Custom check failed for resource %s.", rootBlock.FullName())),
 				)
 			},
 		})
